decorated_flutter library

Classes

AbstractConnectableStream<T, S extends Subject<T>, R extends Stream<T>>
Base class for implementations of ConnectableStream. S is type of the forwarding Subject. R is return type of autoConnect and refCount (type constraint: S extends R).
AlignBottom
AlignEnd
AlignLeft
AlignRight
AlignStart
AlignTop
AnimatedDouble
AnimatedEdgeFade
AnimatedInt
AnimatedShaderMask
AnimatedVisibility
AnimationConfig
AssetPath
AutoCloseKeyboard
参考实现 https://api.flutter.dev/flutter/widgets/EditableTextTapUpOutsideIntent-class.html
AutoScrollBottomSheet
AutoSizeGroup
Controller to synchronize the fontSize of multiple AutoSizeTexts.
AutoSizeGroupBuilder
A Flutter widget that provides an AutoSizeGroup to its builder function.
AutoSizeText
Flutter widget that automatically resizes text to fit perfectly within its bounds.
BackGestureDetector
BackgroundBlur
背景模糊
BackgroundTransformer
The default Transformer for Dio.
BaseIO<T>
BaseOptions
A set of base settings for each Dio(). BaseOptions and Options will be merged into one RequestOptions before sending the requests. See Options.compose.
BehaviorSubject<T>
A special StreamController that captures the latest item that has been added to the controller, and emits that as the first item to any new listener.
BizException
业务异常
BLoC
BLoCProvider<T extends BLoC>
Blur
模糊子widget
BlurDialog
BodyWithSideSheet
An implementaion of Material Side Sheet suggested by Google. Generally to be used with Scaffold's body property. Should only to be used within Web or Desktop.
BoolIO
只接收bool类型数据的IO
BoolOutput<ARG>
只接收bool类型数据的Output
BottomLeftPositioned
BottomPositioned
BottomRightPositioned
BufferCountStreamTransformer<T>
Buffers a number of values from the source Stream by count then emits the buffer and clears it, and starts a new buffer each startBufferEvery values. If startBufferEvery is not provided, then new buffers are started immediately at the start of the source and when each buffer closes and is emitted.
BufferStreamTransformer<T>
Creates a Stream where each item is a List containing the items from the source sequence.
BufferTestStreamTransformer<T>
Creates a Stream where each item is a List containing the items from the source sequence, batched whenever test passes.
CancelToken
Controls cancellation of Dio's requests.
CaptchaBuilder
Capturer
CenterPositioned
Circle
CircleCheckbox
官方checkbox变体
CircularBuffer<T>
A CircularBuffer with a fixed capacity supporting all List operations
CityPickerData
CityPickerResult
CityRegion
CloseKeyboardConfig
Codec
CombineLatestStream<T, R>
Merges the given Streams into one Stream sequence by using the combiner function whenever any of the source stream sequences emits an item.
CompositeSubscription
Acts as a container for multiple subscriptions that can be canceled at once e.g. view subscriptions in Flutter that need to be canceled on view disposal
Computed<T, R>
对某个io进行变换
ConcatEagerStream<T>
Concatenates all of the specified stream sequences, as long as the previous stream sequence terminated successfully.
ConcatStream<T>
Concatenates all of the specified stream sequences, as long as the previous stream sequence terminated successfully.
ConnectableStream<T>
A ConnectableStream resembles an ordinary Stream, except that it can be listened to multiple times and does not begin emitting items when it is listened to, but only when its connect method is called.
ConnectableStreamSubscription<T>
A special StreamSubscription that not only cancels the connection to the source Stream, but also closes down a subject that drives the Stream.
CoordConvert
Countdown
CoverCard
CustomMaterialRoute<T>
DashedLine
DashedLinePainter
DataNotification<T>
A notification representing a data event from a Stream.
DebouncedTextFormField
可以设置在停止接收到TextFieldonChanged方法多久后再触发DebounceTextFieldonChanged方法 适用场景: TextField一边输入内容, 一边根据内容进行网络请求(或其他耗资源的操作), 这时需要 根据输入的节奏来调整网络请求的次数, interval参数可以设置在用户停止输入多久之后, 开始网络 请求(或其他耗资源操作).
DebounceStreamTransformer<T>
Transforms a Stream so that will only emit items from the source sequence if a window has completed, without the source sequence emitting another item.
DecoratedApp<B extends RootBLoC>
DecoratedColumn
DecoratedCupertinoRoute<B extends BLoC, T extends Object>
DecoratedDialogRoute<B extends BLoC, T>
B是指定的BLoC, T是Route的返回类型
DecoratedFlex
DecoratedList
DecoratedRoute<B extends BLoC, T>
B是指定的BLoC, T是Route的返回类型
DecoratedRow
DecoratedScrollable
内部Scrollable滚动时, 动画显示BoxDecoration
DecoratedScrollableConfig
DecoratedStack
DecoratedText
DecoratedWidget<B extends BLoC>
B是指定的BLoC
DecoratedWrap
DefaultIfEmptyStreamTransformer<S>
Emit items from the source Stream, or a single default item if the source Stream emits nothing.
DeferStream<T>
The defer factory waits until a listener subscribes to it, and then it creates a Stream with the given factory function.
Delayed<T>
DelayStreamTransformer<S>
The Delay operator modifies its source Stream by pausing for a particular increment of time (that you specify) before emitting each of the source Stream’s items. This has the effect of shifting the entire sequence of items emitted by the Stream forward in time by that specified increment.
DelayWhenStreamTransformer<T>
Delays the emission of items from the source Stream by a given time span determined by the emissions of another Stream.
DematerializeStreamTransformer<S>
Converts the onData, onDone, and onError StreamNotification objects from a materialized stream into normal onData, onDone, and onError events.
Dio
Dio enables you to make HTTP requests easily.
DioMixin
DistinctUniqueStreamTransformer<S>
Create a Stream which implements a HashSet under the hood, using the provided equals as equality.
DoneNotification
A notification representing a done event from a Stream.
DoStreamTransformer<S>
Invokes the given callback at the corresponding point the the stream lifecycle. For example, if you pass in an onDone callback, it will be invoked when the stream finishes emitting items.
DotTabIndicator
DoubleBackExitApp
连续点击返回按钮退出应用, 如果要使用默认的提示信息(由SnackBar实现)的话, 那么要放在Scaffold 下方!
DynamicFont
EdgeFade
Empty
EmptyPlaceholder
EndWithManyStreamTransformer<S>
Appends a sequence of values to the source Stream.
EndWithStreamTransformer<S>
Appends a value to the source Stream before closing.
ErrorAndStackTrace
An Object which acts as a tuple containing both an error and the corresponding stack trace.
ErrorInterceptorHandler
The handler for interceptors to handle error occurred during the request.
ErrorNotification
A notification representing an error event from a Stream.
ErrorPlaceholder
ExhaustMapStreamTransformer<S, T>
Converts events from the source stream into a new Stream using a given mapper. It ignores all items from the source stream until the new stream completes.
FadeSlideTransition
Faker
FlatMapStreamTransformer<S, T>
Converts each emitted item into a new Stream using the given mapper function, while limiting the maximum number of concurrent subscriptions to these Streams. The newly created Stream will be listened to and begin emitting items downstream.
FlexConfig
ForkJoinStream<T, R>
This operator is best used when you have a group of streams and only care about the final emitted value of each. One common use case for this is if you wish to issue multiple requests on page load (or some other event) and only want to take action when a response has been received for all.
FormData
A class to create readable "multipart/form-data" streams. It can be used to submit forms and file uploads to http server.
FractionalScreen
FromCallableStream<T>
Returns a Stream that, when listening to it, calls a function you specify and then emits the value returned from that function.
FusedTransformer
A Transformer that has a fast path for decoding UTF8-encoded JSON. If the response is utf8-encoded JSON and no custom decoder is specified in the RequestOptions, this transformer is significantly faster than the default SyncTransformer and the BackgroundTransformer. This improvement is achieved by using a fused Utf8Decoder and JsonDecoder to decode the response, which is faster than decoding the utf8-encoded JSON in two separate steps, since Dart uses a special fast decoder for this case. See https://github.com/dart-lang/sdk/blob/5b2ea0c7a227d91c691d2ff8cbbeb5f7f86afdb9/sdk/lib/_internal/vm/lib/convert_patch.dart#L40
GlobalBLoC
全局BLoC, 全局BLoC和局部BLoC目前没用什么功能上的区别, 只是做一下区分
GradientButton
GroupByStreamTransformer<T, K>
The GroupBy operator divides a Stream that emits items into a Stream that emits GroupedStream, each one of which emits some subset of the items from the original source Stream.
GroupedStream<T, K>
The Stream used by GroupByStreamTransformer, it contains events that are grouped by a key value.
Headers
The headers class for requests and responses.
HeroDialogRoute<T>
支持 Hero 转场的透明弹窗路由
HeroOverlay<T>
不切换路由的 Hero 风格弹窗控制器。
HeroOverlayScope
OverlayHero 提供配对范围。
HeroOverlayScopeState
HeroOverlayScope 的状态。
HttpClientAdapter
HttpAdapter is a bridge between Dio and HttpClient.
IgnoreElementsStreamTransformer<S>
Creates a Stream where all emitted items are ignored, only the error / completed notifications are passed
ILogger
ImageView
ImageViewProvider
ImmersiveScrollable
沉浸式的可滚动容器
Input<T>
只输入数据的业务单元
Interceptor
Interceptor helps to deal with RequestOptions, Response, and DioException during the lifecycle of a request before it reaches users.
Interceptors
A Queue-Model list for Interceptors.
InterceptorsWrapper
A helper class to create interceptors in ease.
InterruptNotification
IntervalStreamTransformer<S>
Creates a Stream that emits each item in the Stream after a given duration.
IntInput
只接收int类型数据的Input
IntIO
只接收int类型数据的IO
IO<T>
既可以输入又可以输出的事件
KeyboardHeightBuilder
Builds (and rebuilds) a builder with the current height of the software keyboard.
LazyIndexedStack
LeftPositioned
Line
ListInput<T>
内部数据类型是List的输入业务单元
ListIO<T>
内部数据类型是List的输入输出业务单元
ListOutput<T, ARG>
内部数据类型是List的输出业务单元
ListParam<T>
Indicates a param being used as queries or form data, and how does it gets formatted.
ListStreamOutput<T>
内部数据类型是List的输出业务单元
ListWrapper<T>
列表+元信息
LoadingElevatedButton
带加载中动画的按钮
LoadingWidget
LoadMore
为任意可滚动组件提供加载更多能力。
LoadMoreConfig
LocalBLoC
局部BLoC, 局部BLoC通常包在Screen的外面, 作用范围就是这个Screen内部
LocalNavigator
LocalNavigatorConfig
LogInterceptor
LogInterceptor is used to print logs during network requests. It should be the last interceptor added, otherwise modifications by following interceptors will not be logged. This is because the execution of interceptors is in the order of addition.
MapNotNullStreamTransformer<T, R extends Object>
Create a Stream containing only the non-null results of applying the given transform function to each element of the Stream.
MapToStreamTransformer<S, T>
Emits the given constant value on the output Stream every time the source Stream emits a value.
MaterializeStreamTransformer<S>
Converts the onData, on Done, and onError events into StreamNotification objects that are passed into the downstream onData listener.
MaxScaleTextWidget
MergeStream<T>
Flattens the items emitted by the given streams into a single Stream sequence.
ModalLoading
MultiListenableBuilder
Builder that runs every time one of the given listenables changes.
MultipartFile
An upload content that is a part of MultipartRequest. This doesn't need to correspond to a physical file.
NeverStream<T>
Returns a non-terminating stream sequence, which can be used to denote an infinite duration.
NoClipSizeTransition
内置的SizeTransition会带有ClipRect, 导致阴影被切, 这里去掉相关逻辑
NotifierSwitch
NoTransitionsPageBuilder
NumberRange<T extends num>
OnErrorResumeStreamTransformer<S>
Intercepts error events and switches to a recovery stream created by the provided recoveryFn Function.
OptionalInput<T>
只输入数据的业务单元
OptionalIntInput
只接收int类型数据的Input
OptionalIntIO
只接收int类型数据的IO
OptionalIO<T>
既可以输入又可以输出的事件
OptionalListInput<T>
内部数据类型是List的输入业务单元
OptionalListIO<T>
内部数据类型是List的输入输出业务单元
OptionalListOutput<T, ARG>
内部数据类型是List的输出业务单元
OptionalOutput<T, ARG>
只输出数据的业务单元
OptionalPageIO<T, ARG>
分页业务单元
OptionalPageOutput<T, ARG>
分页业务单元
OptionalStreamOutput<T>
转发上游流的业务单元
Options
The configuration for a single request. BaseOptions and Options will be merged into one RequestOptions before sending the requests. See Options.compose.
Output<T, ARG>
只输出数据的业务单元
OverflowText
文本溢出时,在最后一行尾部展示自定义组件。
OverlayHero
标记 Hero 弹窗中的共享元素。
PageIO<T, ARG>
分页业务单元
PageOutput<T, ARG>
分页业务单元
PairwiseStreamTransformer<T>
Emits the n-th and n-1th events as a pair. The first event won't be emitted until the second one arrives.
PersistConfig<T>
Persistence
PreferredNestedScrollView
PreferredTabController
PrimaryIcon
使用primaryColor的Icon
PrimaryScrollControllerConfig
PublishConnectableStream<T>
A ConnectableStream that converts a single-subscription Stream into a broadcast Stream.
PublishSubject<T>
Exactly like a normal broadcast StreamController with one exception: this class is both a Stream and Sink.
QueuedInterceptor
Interceptor in queue.
QueuedInterceptorsWrapper
A helper class to create QueuedInterceptor in ease.
RaceStream<T>
Given two or more source streams, emit all of the items from only the first of these streams to emit an item or notification.
Range<T extends Comparable<T>>
RangeStream
Returns a Stream that emits a sequence of Integers within a specified range.
RangeTextInputFormatter
ReCase
An instance of text to be re-cased.
RedirectRecord
A record that records the redirection happens during requests, including status code, request method, and the location.
RenderSliverStack
Repeat
RepeatStream<T>
Creates a Stream that will recreate and re-listen to the source Stream the specified number of times until the Stream terminates successfully.
ReplayConnectableStream<T>
A ConnectableStream that converts a single-subscription Stream into a broadcast Stream that replays emitted items to any new listener, and provides synchronous access to the list of emitted values.
ReplayStream<T>
An Stream that provides synchronous access to the emitted values
ReplaySubject<T>
A special StreamController that captures all of the items that have been added to the controller, and emits those as the first items to any new listener.
RequestInterceptorHandler
The handler for interceptors to handle before the request has been sent.
RequestOptions
The internal request option class that is the eventual result after BaseOptions and Options are composed.
Response<T>
The Response class contains the payload (could be transformed) that respond from the request, and other information of the response.
ResponseBody
The response wrapper class for adapters.
ResponseInterceptorHandler
The handler for interceptors to handle after respond.
RetryOptions
Object holding options for retrying a function.
RetryStream<T>
Creates a Stream that will recreate and re-listen to the source Stream the specified number of times until the Stream terminates successfully.
RetryWhenStream<T>
Creates a Stream that will recreate and re-listen to the source Stream when the notifier emits a new value. If the source Stream emits an error or it completes, the Stream terminates.
RightPositioned
RootBLoC
顶层BLoC, 这个BLoC只有子BLoC, 没有Event, 并且子BLoC都是GlobalBLoC
RouteLauncher
全局路由启动器
Runtime
显示运行时信息的widget
RuntimeScaffold<T extends LocalBLoC>
Rx
A utility class that provides static methods to create the various Streams provided by RxDart.
RxAnimatedSize
RxVisibility
SafeAreaConfig
SampleStreamTransformer<T>
A StreamTransformer that, when the specified window Stream emits an item or completes, emits the most recently emitted item (if any) emitted by the source Stream since the previous emission from the sample Stream.
ScaleTabBar
A Material Design primary tab bar.
ScanStreamTransformer<S, T>
Applies an accumulator function over an stream sequence and returns each intermediate result. The seed value is used as the initial accumulator value.
ScrollableTopDivider
SequenceEqualStream<S, T>
Determine whether two Streams emit the same sequence of items. You can provide an optional equals handler to determine equality.
ShowMoreText
ShowUpTransition
Signal
没有数据, 只发射信号的IO
SingleSubscriber<T>
SkipLastStreamTransformer<T>
Skip the last count items emitted by the source Stream
SkipUntilStreamTransformer<S, T>
Starts emitting events only after the given stream emits an event.
SliverClip
SliverClip clips its sliver child from its paintOrigin to its paintExtent. Also clips off any overlap if clipOverlap is true
SliverConfig
SliverPositioned
A widget that controls where a box child of a SliverStack is positioned.
SliverStack
拷贝自 https://github.com/Kavantix/sliver_tools/blob/master/lib/src/rendering/sliver_stack.dart A Stack widget that can be used as a sliver
SliverStackParentData
SnapList
SpringButton
SpringButtonState
SpringContainer
带有缩放动画的按钮
Square
StartWithManyStreamTransformer<S>
Prepends a sequence of values to the source Stream.
StartWithStreamTransformer<S>
Prepends a value to the source Stream.
StreamMapper<T, R>
对某个io进行变换
StreamNotification<T>
A class that encapsulates the NotificationKind of event, value of the event in case of onData, or the Error in the case of onError. A container object that wraps the NotificationKind of event (OnData, OnDone, OnError), and the item or error that was emitted. In the case of onDone, no data is emitted as part of the StreamNotification.
StreamOutput<T>
转发上游流的业务单元
StringSelectable
字符串可选
Subject<T>
The base for all Subjects. If you'd like to create a new Subject, extend from this class.
Subscriber<T>
SwitchIfEmptyStreamTransformer<S>
When the original stream emits no items, this operator subscribes to the given fallback stream and emits items from that stream instead.
SwitchLatestStream<T>
Convert a Stream that emits Streams (aka a 'Higher Order Stream') into a single Stream that emits the items emitted by the most-recently-emitted of those Streams.
SwitchMapStreamTransformer<S, T>
Converts each emitted item into a new Stream using the given mapper function. The newly created Stream will be be listened to and begin emitting items, and any previously created Stream will stop emitting.
SyncTransformer
If you want to custom the transformation of request/response data, you can provide a Transformer by your self, and replace the transformer by setting the Dio.transformer.
SystemChineseFont
TabControllerConfig
TakeLastStreamTransformer<T>
Emits only the final count values emitted by the source Stream.
TakeUntilStreamTransformer<S, T>
Returns the values from the source stream sequence until the other stream sequence produces a value.
TakeWhileInclusiveStreamTransformer<S>
Emits values emitted by the source Stream so long as each value satisfies the given test. When the test is not satisfied by a value, it will emit this value as a final event and then complete.
TBD
ThrottleInterceptor
ThrottleStreamTransformer<T>
A StreamTransformer that emits a value from the source Stream, then ignores subsequent source values while the window Stream is open, then repeats this process.
TimeInterval<T>
A class that represents a snapshot of the current value emitted by a Stream, at a specified interval.
TimeIntervalStreamTransformer<S>
Records the time interval between consecutive values in an stream sequence.
TimeOfDayRange
一天内的时间范围。
TimerStream<T>
Emits the given value after a specified amount of time.
Timestamped<T>
A class that represents a snapshot of the current value emitted by a Stream, at a specified timestamp.
TimestampStreamTransformer<S>
Wraps each item emitted by the source Stream in a Timestamped object that includes the emitted item and the time when the item was emitted.
Toggleable
TopDividerConfig
TopLeftPositioned
TopPositioned
TopRightPositioned
Transformer
Transformer allows changes to the request/response data before it is sent/received to/from the server.
TransparentRoute<T>
UnknownScreen
UriBuilder
UsingStream<T, R>
When listener listens to it, creates a resource object from resource factory function, and creates a Stream from the given factory function and resource as argument. Finally when the stream finishes emitting items or stream subscription is cancelled (call StreamSubscription.cancel or Stream.listen(cancelOnError: true)), call the disposer function on resource object. The disposer is called after the future returned from StreamSubscription.cancel completes.
ValueConnectableStream<T>
A ConnectableStream that converts a single-subscription Stream into a broadcast Stream that replays the latest value to any new listener, and provides synchronous access to the latest emitted value.
ValueListenableSwitcher<T>
ValueStream<T>
A Stream that provides synchronous access to the last emitted value (aka. data event).
VerticalButton
WantKeepAlive
WhereNotNullStreamTransformer<T extends Object>
Create a Stream which emits all the non-null elements of the Stream, in their original emission order.
WhereTypeStreamTransformer<S, T>
This transformer is a shorthand for Stream.where followed by Stream.cast.
WindowCountStreamTransformer<T>
Buffers a number of values from the source Stream by count then emits the buffer as a Stream and clears it, and starts a new buffer each startBufferEvery values. If startBufferEvery is not provided, then new buffers are started immediately at the start of the source and when each buffer closes and is emitted.
WindowStreamTransformer<T>
Creates a Stream where each item is a Stream containing the items from the source sequence.
WindowTestStreamTransformer<T>
Creates a Stream where each item is a Stream containing the items from the source sequence, batched whenever test passes.
WIP
WithLatestFromStreamTransformer<S, T, R>
A StreamTransformer that emits when the source stream emits, combining the latest values from the two streams using the provided function.
ZipStream<T, R>
Merges the specified streams into one stream sequence using the given zipper Function whenever all of the stream sequences have produced an element at a corresponding index.

Enums

Actions
CaptchaState
DioExceptionType
The exception enumeration indicates what type of exception has happened during requests.
ErrorLevel
FileAccessMode
The file access mode when downloading a file, corresponds to a subset of dart:io::FileMode.
Gender
Gravity
ListFormat
Specifies the array format (a single parameter with multiple parameter or multiple parameters with the same name). and the separator for array items.
NotificationKind
The type of event used in StreamNotification
ResponseType
Indicates which transformation should be applied to the response data.
SlideDirection
SnapshotType
SpringButtonType
ZIndex
Zodiac

Mixins

AnimationMixin<T extends StatefulWidget>
BLoCDisposeBag
BoolMixin
Cacheable
DebounceableMixin<T extends StatefulWidget>
DisposeBag<T extends StatefulWidget>
Enable
Extensible
InputMixin<T>
输入单元特有的成员
IntMixin
LifecycleBLoCMixin
ListMixin<T>
内部数据是List特有的成员
OptionalIntMixin
OptionalListMixin<T>
内部数据是List特有的成员
OptionalPageMixin<T, ARG>
OptionsMixin
The mixin class for options that provides common attributes.
OutputMixin<T, ARG>
输出单元特有的成员
PageMixin<T, ARG>
Selectable
Serializable
SingleTickerProviderBLoCMixin
为BLoC提供一个简单的TickerProvider

Extensions

AddToCompositeSubscriptionExtension on StreamSubscription<T>
Extends the StreamSubscription class with the ability to be added to CompositeSubscription container.
BoolX on bool
BufferExtensions on Stream<T>
Extends the Stream class with the ability to buffer events in various ways
BuildContextX on BuildContext
ColorDecoratedExtension on Color
CompleterX on Completer<T>
ConcatExtensions on Stream<T>
Extends the Stream class with the ability to concatenate one stream with another.
ConnectableStreamExtensions on Stream<T>
Extends the Stream class with the ability to transform a single-subscription Stream into a ConnectableStream.
DateTimeRangeX on DateTimeRange<DateTime>
DateTimeX on DateTime
DebounceExtensions on Stream<T>
Extends the Stream class with the ability to debounce events in various ways
DefaultIfEmptyExtension on Stream<T>
DelayExtension on Stream<T>
Extends the Stream class with the ability to delay events being emitted
DelayWhenExtension on Stream<T>
Extends the Stream class with the ability to delay events being emitted.
DematerializeExtension on Stream<StreamNotification<T>>
Converts the onData, onDone, and onError StreamNotifications from a materialized stream into normal onData, onDone, and onError events.
DirectoryX on Directory
DistinctUniqueExtension on Stream<T>
Extends the Stream class with the ability to skip items that have previously been emitted.
DoExtensions on Stream<T>
Extends the Stream class with the ability to execute a callback function at different points in the Stream's lifecycle.
DoubleX on double
DurationX on Duration
EdgeInsetsX on EdgeInsets
EndWithExtension on Stream<T>
Extends the Stream class with the ability to emit the given value as the final item before closing.
EndWithManyExtension on Stream<T>
Extends the Stream class with the ability to emit the given value as the final item before closing.
EnumX on Enum
ErrorAndStackTracesReplayStreamExtension on ReplayStream<T>
Extension method on ReplayStream to access the emitted ErrorAndStackTraces.
ErrorAndStackTraceValueStreamExtension on ValueStream<T>
Extension method on ValueStream to access the last emitted ErrorAndStackTrace.
ExhaustMapExtension on Stream<T>
Extends the Stream class with the ability to transform the Stream into a new Stream. The new Stream emits items and ignores events from the source Stream until the new Stream completes.
FileSystemEntityX on FileSystemEntity
FileX on File
FlatMapExtension on Stream<T>
Extends the Stream class with the ability to convert the source Stream into a new Stream each time the source emits an item.
FlutterViewX on FlutterView
FutureIterableX on Iterable<Future<T>>
FutureX on Future<T>
GlobalKeyX on GlobalKey<State<StatefulWidget>>
GroupByExtension on Stream<T>
Extends the Stream class with the ability to convert events into Streams of events that are united by a key.
IgnoreElementsExtension on Stream<T>
Extends the Stream class with the ability to skip, or ignore, data events.
ImageProviderX on ImageProvider<Object>
IntervalExtension on Stream<T>
Extends the Stream class with the ability to emit each item after a given duration.
IntX on int
IterableFutureX on Future<Iterable<T>>
IterableX on Iterable<T>
KtStandardExtension on T
LastEventValueStreamExtensions on ValueStream<T>
Extension methods on ValueStream related to lastEventOrNull.
ListStreamX on Stream<List<T>>
ListX on List<T>
LocaleIterableX on Iterable<Locale>
LocaleX on Locale
MapNotNullExtension on Stream<T>
Extends the Stream class with the ability to convert the source Stream to a Stream containing only the non-null results of applying the given transform function to each element of this Stream.
MapToExtension on Stream<S>
Extends the Stream class with the ability to convert each item to the same value.
MapX on Map<K, V>
MaterializeExtension on Stream<T>
Extends the Stream class with the ability to convert the onData, on Done, and onError events into StreamNotifications that are passed into the downstream onData listener.
MaterialStateProperty_BorderSideX on BorderSide
MaterialStateProperty_ColorX on Color
MaterialStateProperty_doubleX on double
MaterialStateProperty_EdgeInsetsX on EdgeInsets
MaterialStateProperty_intX on int
MaterialStateProperty_OutlinedBorderX on OutlinedBorder
MaterialStateProperty_TextStyleX on TextStyle
MaxExtension on Stream<T>
Extends the Stream class with the ability to transform into a Future that completes with the largest item emitted by the Stream.
MergeExtension on Stream<T>
Extends the Stream class with the ability to merge one stream with another.
MinExtension on Stream<T>
Extends the Stream class with the ability to transform into a Future that completes with the smallest item emitted by the Stream.
ModalRouteDecoratedX on ModalRoute
NullableFutureX on Future<T?>
NullableIterableX on Iterable<T?>?
NumIterableX on Iterable<T>
NumX on num
ObjectX on Object
OffsetX on Offset
OnErrorExtensions on Stream<T>
Extends the Stream class with the ability to recover from errors in various ways
OptionalDurationX on Duration?
OptionalNumX on T?
PageControllerX on PageController
PairwiseExtension on Stream<T>
Extends the Stream class with the ability to emit the nth and n-1th events as a pair
RectX on Rect
RouteSettingsX on RouteSettings
SampleExtensions on Stream<T>
Extends the Stream class with the ability to sample events from the Stream
ScanExtension on Stream<T>
Extends
ScrollControllerX on ScrollController
SelectableListStreamX on Stream<List<Selectable>>
SelectableListX on List<T>
SharedPreferencesX on SharedPreferences
SizeX on Size
SkipLastExtension on Stream<T>
Extends the Stream class with the ability to skip the last count items emitted by the source Stream
SkipUntilExtension on Stream<T>
Extends the Stream class with the ability to skip events until another Stream emits an item.
StartWithExtension on Stream<T>
Extends the Stream class with the ability to emit the given value as the first item.
StartWithManyExtension on Stream<T>
Extends the Stream class with the ability to emit the given values as the first items.
StateX on State<StatefulWidget>
StreamNotificationExtensions on StreamNotification<T>
Provides extension methods on StreamNotification.
StringFutureX on Future<String>
StringReCase on String
StringStream on Stream<String>
StringX on String
SwitchIfEmptyExtension on Stream<T>
Extend the Stream class with the ability to return an alternative Stream if the initial Stream completes with no items.
SwitchMapExtension on Stream<T>
Extends the Stream with the ability to convert one stream into a new Stream whenever the source emits an item. Every time a new Stream is created, the previous Stream is discarded.
TabControllerX on TabController
TakeLastExtension on Stream<T>
Extends the Stream class with the ability receive only the final count events from the source Stream.
TakeUntilExtension on Stream<T>
Extends the Stream class with the ability receive events from the source Stream until another Stream produces a value.
TakeWhileInclusiveExtension on Stream<T>
Extends the Stream class with the ability to take events while they pass the condition given and include last event that doesn't pass the condition.
TextEditingControllerX on TextEditingController
TextStyleUseSystemChineseFont on TextStyle
TextThemeUseSystemChineseFont on TextTheme
TextX on Text
ThemeDataUseSystemChineseFont on ThemeData
ThrottleExtensions on Stream<T>
Extends the Stream class with the ability to throttle events in various ways
TimeIntervalExtension on Stream<T>
Extends the Stream class with the ability to record the time interval between consecutive values in an stream
TimeStampExtension on Stream<T>
Extends the Stream class with the ability to wrap each item emitted by the source Stream in a Timestamped object that includes the emitted item and the time when the item was emitted.
ValueNotifierBoolX on ValueNotifier<bool>
ValueNotifierIntX on ValueNotifier<int>
ValueNotifierListX on ValueNotifier<Iterable<T>>
ValueNotifierX on ValueNotifier<T>
WhereNotNullExtension on Stream<T?>
Extends the Stream class with the ability to convert the source Stream to a Stream which emits all the non-null elements of this Stream, in their original emission order.
WhereTypeExtension on Stream<T>
Extends the Stream class with the ability to filter down events to only those of a specific type.
WidgetX on Widget
WindowExtensions on Stream<T>
Extends the Stream class with the ability to window
WithLatestFromExtensions on Stream<T>
Extends the Stream class with the ability to merge the source Stream with the last emitted item from another Stream.
ZipWithExtension on Stream<T>
Extends the Stream class with the ability to zip one Stream with another.

Constants

anyString → const String
assetPath → const AssetPath
borderSide → const BorderSide
kDivider0 → const Divider
kDivider1 → const Divider
kDivider12 → const Divider
kDivider16 → const Divider
kDivider2 → const Divider
kDivider24 → const Divider
kDivider4 → const Divider
kDivider48 → const Divider
kDivider64 → const Divider
kDivider8 → const Divider
kSpace0 → const double
kSpace1 → const double
kSpace12 → const double
kSpace16 → const double
kSpace2 → const double
kSpace24 → const double
kSpace32 → const double
kSpace4 → const double
kSpace40 → const double
kSpace48 → const double
kSpace56 → const double
kSpace6 → const double
kSpace64 → const double
kSpace8 → const double
leftRightBorder → const Border
NIL → const SizedBox
PREFERRED_NIL → const PreferredSize
SLIVER_NIL → const SliverToBoxAdapter
SLIVER_SPACE_1 → const SliverToBoxAdapter
SLIVER_SPACE_10 → const SliverToBoxAdapter
SLIVER_SPACE_10_HORIZONTAL → const SliverToBoxAdapter
SLIVER_SPACE_10_VERTICAL → const SliverToBoxAdapter
SLIVER_SPACE_12 → const SliverToBoxAdapter
SLIVER_SPACE_12_HORIZONTAL → const SliverToBoxAdapter
SLIVER_SPACE_12_VERTICAL → const SliverToBoxAdapter
SLIVER_SPACE_16 → const SliverToBoxAdapter
SLIVER_SPACE_16_HORIZONTAL → const SliverToBoxAdapter
SLIVER_SPACE_16_VERTICAL → const SliverToBoxAdapter
SLIVER_SPACE_1_HORIZONTAL → const SliverToBoxAdapter
SLIVER_SPACE_1_VERTICAL → const SliverToBoxAdapter
SLIVER_SPACE_2 → const SliverToBoxAdapter
SLIVER_SPACE_20 → const SliverToBoxAdapter
SLIVER_SPACE_20_HORIZONTAL → const SliverToBoxAdapter
SLIVER_SPACE_20_VERTICAL → const SliverToBoxAdapter
SLIVER_SPACE_24 → const SliverToBoxAdapter
SLIVER_SPACE_24_HORIZONTAL → const SliverToBoxAdapter
SLIVER_SPACE_24_VERTICAL → const SliverToBoxAdapter
SLIVER_SPACE_2_HORIZONTAL → const SliverToBoxAdapter
SLIVER_SPACE_2_VERTICAL → const SliverToBoxAdapter
SLIVER_SPACE_32 → const SliverToBoxAdapter
SLIVER_SPACE_32_HORIZONTAL → const SliverToBoxAdapter
SLIVER_SPACE_32_VERTICAL → const SliverToBoxAdapter
SLIVER_SPACE_4 → const SliverToBoxAdapter
SLIVER_SPACE_40 → const SliverToBoxAdapter
SLIVER_SPACE_40_HORIZONTAL → const SliverToBoxAdapter
SLIVER_SPACE_40_VERTICAL → const SliverToBoxAdapter
SLIVER_SPACE_48 → const SliverToBoxAdapter
SLIVER_SPACE_48_HORIZONTAL → const SliverToBoxAdapter
SLIVER_SPACE_48_VERTICAL → const SliverToBoxAdapter
SLIVER_SPACE_4_HORIZONTAL → const SliverToBoxAdapter
SLIVER_SPACE_4_VERTICAL → const SliverToBoxAdapter
SLIVER_SPACE_56 → const SliverToBoxAdapter
SLIVER_SPACE_56_HORIZONTAL → const SliverToBoxAdapter
SLIVER_SPACE_56_VERTICAL → const SliverToBoxAdapter
SLIVER_SPACE_6 → const SliverToBoxAdapter
SLIVER_SPACE_64 → const SliverToBoxAdapter
SLIVER_SPACE_64_HORIZONTAL → const SliverToBoxAdapter
SLIVER_SPACE_64_VERTICAL → const SliverToBoxAdapter
SLIVER_SPACE_6_HORIZONTAL → const SliverToBoxAdapter
SLIVER_SPACE_6_VERTICAL → const SliverToBoxAdapter
SLIVER_SPACE_8 → const SliverToBoxAdapter
SLIVER_SPACE_8_HORIZONTAL → const SliverToBoxAdapter
SLIVER_SPACE_8_VERTICAL → const SliverToBoxAdapter
SLIVER_SPACE_ZERO → const SliverToBoxAdapter
SPACE_1 → const SizedBox
SPACE_10 → const SizedBox
SPACE_10_HORIZONTAL → const SizedBox
SPACE_10_HORIZONTAL_SPAN → const WidgetSpan
SPACE_10_SPAN → const WidgetSpan
SPACE_10_VERTICAL → const SizedBox
SPACE_10_VERTICAL_SPAN → const WidgetSpan
SPACE_12 → const SizedBox
SPACE_12_HORIZONTAL → const SizedBox
SPACE_12_HORIZONTAL_SPAN → const WidgetSpan
SPACE_12_SPAN → const WidgetSpan
SPACE_12_VERTICAL → const SizedBox
SPACE_12_VERTICAL_SPAN → const WidgetSpan
SPACE_16 → const SizedBox
SPACE_16_HORIZONTAL → const SizedBox
SPACE_16_HORIZONTAL_SPAN → const WidgetSpan
SPACE_16_SPAN → const WidgetSpan
SPACE_16_VERTICAL → const SizedBox
SPACE_16_VERTICAL_SPAN → const WidgetSpan
SPACE_1_HORIZONTAL → const SizedBox
SPACE_1_HORIZONTAL_SPAN → const WidgetSpan
SPACE_1_SPAN → const WidgetSpan
SPACE_1_VERTICAL → const SizedBox
SPACE_1_VERTICAL_SPAN → const WidgetSpan
SPACE_2 → const SizedBox
SPACE_20 → const SizedBox
SPACE_20_HORIZONTAL → const SizedBox
SPACE_20_HORIZONTAL_SPAN → const WidgetSpan
SPACE_20_SPAN → const WidgetSpan
SPACE_20_VERTICAL → const SizedBox
SPACE_20_VERTICAL_SPAN → const WidgetSpan
SPACE_24 → const SizedBox
SPACE_24_HORIZONTAL → const SizedBox
SPACE_24_HORIZONTAL_SPAN → const WidgetSpan
SPACE_24_SPAN → const WidgetSpan
SPACE_24_VERTICAL → const SizedBox
SPACE_24_VERTICAL_SPAN → const WidgetSpan
SPACE_2_HORIZONTAL → const SizedBox
SPACE_2_HORIZONTAL_SPAN → const WidgetSpan
SPACE_2_SPAN → const WidgetSpan
SPACE_2_VERTICAL → const SizedBox
SPACE_2_VERTICAL_SPAN → const WidgetSpan
SPACE_32 → const SizedBox
SPACE_32_HORIZONTAL → const SizedBox
SPACE_32_HORIZONTAL_SPAN → const WidgetSpan
SPACE_32_SPAN → const WidgetSpan
SPACE_32_VERTICAL → const SizedBox
SPACE_32_VERTICAL_SPAN → const WidgetSpan
SPACE_4 → const SizedBox
SPACE_40 → const SizedBox
SPACE_40_HORIZONTAL → const SizedBox
SPACE_40_HORIZONTAL_SPAN → const WidgetSpan
SPACE_40_SPAN → const WidgetSpan
SPACE_40_VERTICAL → const SizedBox
SPACE_40_VERTICAL_SPAN → const WidgetSpan
SPACE_48 → const SizedBox
SPACE_48_HORIZONTAL → const SizedBox
SPACE_48_HORIZONTAL_SPAN → const WidgetSpan
SPACE_48_SPAN → const WidgetSpan
SPACE_48_VERTICAL → const SizedBox
SPACE_48_VERTICAL_SPAN → const WidgetSpan
SPACE_4_HORIZONTAL → const SizedBox
SPACE_4_HORIZONTAL_SPAN → const WidgetSpan
SPACE_4_SPAN → const WidgetSpan
SPACE_4_VERTICAL → const SizedBox
SPACE_4_VERTICAL_SPAN → const WidgetSpan
SPACE_56 → const SizedBox
SPACE_56_HORIZONTAL → const SizedBox
SPACE_56_HORIZONTAL_SPAN → const WidgetSpan
SPACE_56_SPAN → const WidgetSpan
SPACE_56_VERTICAL → const SizedBox
SPACE_56_VERTICAL_SPAN → const WidgetSpan
SPACE_6 → const SizedBox
SPACE_64 → const SizedBox
SPACE_64_HORIZONTAL → const SizedBox
SPACE_64_HORIZONTAL_SPAN → const WidgetSpan
SPACE_64_SPAN → const WidgetSpan
SPACE_64_VERTICAL → const SizedBox
SPACE_64_VERTICAL_SPAN → const WidgetSpan
SPACE_6_HORIZONTAL → const SizedBox
SPACE_6_HORIZONTAL_SPAN → const WidgetSpan
SPACE_6_SPAN → const WidgetSpan
SPACE_6_VERTICAL → const SizedBox
SPACE_6_VERTICAL_SPAN → const WidgetSpan
SPACE_8 → const SizedBox
SPACE_8_HORIZONTAL → const SizedBox
SPACE_8_HORIZONTAL_SPAN → const WidgetSpan
SPACE_8_SPAN → const WidgetSpan
SPACE_8_VERTICAL → const SizedBox
SPACE_8_VERTICAL_SPAN → const WidgetSpan
SPACE_ZERO → const SizedBox
SPACE_ZERO_SPAN → const WidgetSpan
tbd → const TBD
表示待定(To be determined)
topBottomBorder → const Border
wip → const WIP
表示处理中

Properties

anyObject → dynamic
当不关心对象是什么, 但是又必须存在一个对象的时候, 使用这个
final
gDecoratedStorage → SharedPreferences
no setter
gNavigator NavigatorState
no setter
gNavigatorKey GlobalKey<NavigatorState>
final
handleCustomError ValueChanged<Object>?
getter/setter pair
kEmailRegex RegExp
final
kIpV4Regex RegExp
final
kMoneyRegex RegExp
final
L → Logger
final
r Random
final
SPACE_STATUS_BAR SizedBox
final

Functions

clearFocus(BuildContext context) → void
combine2<T1, T2>(Stream<T1> streamA, Stream<T2> streamB) Stream<(T1, T2)>
combine3<T1, T2, T3>(Stream<T1> streamA, Stream<T2> streamB, Stream<T3> streamC) Stream<(T1, T2, T3)>
combine4<T1, T2, T3, T4>(Stream<T1> streamA, Stream<T2> streamB, Stream<T3> streamC, Stream<T4> streamD) Stream<(T1, T2, T3, T4)>
computeLineCount(String text, TextStyle style, double maxWidth) int
computeTextHeight(String text, TextStyle style, double maxWidth) double
createAnimation(TickerProvider vsync, {required ValueChanged<double> callback, required Duration duration, Curve curve = Curves.ease, double lowerBound = 0, double upperBound = 1}) AnimationController
currentMonth([DateTime? date]) DateTime
当前月
currentYear([DateTime? date]) DateTime
当前年
debounce(Duration duration, void decorated()) → void Function()
对一个函数decorated做防抖处理
defaultDioExceptionReadableStringBuilder(DioException e) String
The default implementation of building a readable string of DioException.
doFunc<T>(T func()) → T
执行一段回调
doNothing() → void
doNothing1(dynamic _) → void
doNothing2(dynamic _, dynamic __) → void
enumName(dynamic enumValue) String
filesize(dynamic size, [int round = 2]) String
获取文件大小
generateRandomString(int len) String
getFirst<T>(List<T> list) → T
getFirstOrNull<T>(List<T> list) → T?
getTmpFile(Uint8List? bytes, {required Directory dir, String ext = ''}) Future<File?>
写入一个临时文件
handleError(Object error, [StackTrace? trace]) → dynamic
hideKeyboard() Future<void>
关闭键盘
highContrast(Color input) Color
initDecoratedBox() Future<void>
isAllEmpty(List<Object?>? list) bool
isAllNotEmpty(List<Object?>? list) bool
isEmpty(Object? object) bool
isFalse(bool? data) bool
isJsonable(Object? object) bool
是否可以转换为json的
isNotEmpty(Object? object) bool
isNull(dynamic data) bool
isTrue(bool? data) bool
logTime([String? tag]) DateTime
打印当前时间
maxValue<T extends Comparable>(T value1, T value2) → T
求最大值
md5Of(List<int> input) String
获取md5
md5OfFile(File file, {int streamThreshold = 10 * 1024 * 1024}) Future<String>
获取md5
md5OfStream(Stream<Uint8List> stream) Future<String>
获取md5
md5OfString(String input) String
获取md5
minValue<T extends Comparable>(T value1, T value2) → T
求最小值
nextFrame(VoidCallback cb) → void
下一帧回调
nextMonth([DateTime? date]) DateTime
下一个月
nextYear([DateTime? date]) DateTime
下一年
notEqual(dynamic prev, dynamic next) bool
notNull(dynamic data) bool
passthrough<T>(T data) → T
透传
polling({required Future<void> task(), required Duration interval, required int maxTryCount, Future<void> whenErrorTry()?}) Future<void>
通用轮询逻辑
prevMonth([DateTime? date]) DateTime
前一个月
prevYear([DateTime? date]) DateTime
前一年
pushRemoveUntil<T extends Object?, TO extends Object?>(String path, RoutePredicate predicate, {Map<String, String?>? query, Map<String, Object?>? body, BuildContext? context}) Future<T?>
push一个路由并弹出指定路由
pushRoute<T>(String path, {Map<String, String?>? query, Map<String, Object?>? body, BuildContext? context}) Future<T?>
push一个路由
randomNumber(int len) String
生成指定长度的随机数字
randomString(int len) String
生成指定长度的随机字符串
replaceRoute<T extends Object?, TO extends Object?>(String path, {Map<String, String?>? query, Map<String, Object?>? body, BuildContext? context}) Future<T?>
替换一个路由
requireDate(dynamic raw, {DateTime fallback()?}) DateTime
强制解析出一个日期
resetSelectable(Selectable selectable) → void
retry<T>(FutureOr<T> fn(), {Duration delayFactor = const Duration(milliseconds: 200), double randomizationFactor = 0.25, Duration maxDelay = const Duration(seconds: 30), int maxAttempts = 8, FutureOr<bool> retryIf(Object)?, FutureOr<bool> onRetry(Object)?}) Future<T>
Call fn retrying so long as retryIf return true for the exception thrown, up-to maxAttempts times.
returnFalse() bool
returnNull<T>() → T?
returnTrue() bool
runDecoratedApp({required FutureOr<void> appRunner(), FutureOr<void> beforeApp()?, FutureOr<void> afterApp()?, FutureOr<void> onError(Object, StackTrace)?, SystemUiMode? systemUiMode, Color? statusBarColor, Color? systemNavigationBarColor, Color? systemNavigationBarDividerColor, Brightness? statusBarBrightness, Brightness? statusBarIconBrightness, Brightness? systemNavigationBarIconBrightness, bool? systemNavigationBarContrastEnforced, bool? systemStatusBarContrastEnforced, bool zoned = true, bool isTest = false, bool withFileLogger = true}) Future<void>
运行app
safeAs<T>(Object? value) → T?
宽松类型转换
showCityPickerDialog(BuildContext context, {List<CityRegion>? data, CityPickerResult? initialValue, String? initialProvinceCode, String? initialCityCode, String? initialAreaCode, Widget? title, String? cancelText, String? confirmText, double itemExtent = 36}) Future<CityPickerResult?>
showDateDialog(BuildContext context, {DateTime? initialDateTime, DateTime? maximumDate, DateTime? minimumDate, Widget? title, CupertinoDatePickerMode mode = CupertinoDatePickerMode.date, String? cancelText, String? confirmText}) Future<DateTime?>
showHeroDialog<T>(BuildContext context, {required WidgetBuilder builder, bool useRootNavigator = false, bool barrierDismissible = true, Color? barrierColor = Colors.black54, String? barrierLabel = '关闭弹窗', bool useSafeArea = true, Offset transitionOffset = const Offset(0, 20), Duration transitionDuration = const Duration(milliseconds: 200), Duration reverseTransitionDuration = const Duration(milliseconds: 160), Curve curve = Curves.easeOut, Curve reverseCurve = Curves.easeIn}) Future<T?>
打开支持 Hero 动画的透明弹窗
showHeroOverlay<T>(BuildContext context, {required WidgetBuilder builder, bool useRootOverlay = false, bool barrierDismissible = true, Color? barrierColor = Colors.black54, String? barrierLabel = '关闭弹窗', bool useSafeArea = true, Offset transitionOffset = const Offset(0, 20), Duration transitionDuration = const Duration(milliseconds: 200), Duration reverseTransitionDuration = const Duration(milliseconds: 160), Curve curve = Curves.easeOut, Curve reverseCurve = Curves.easeIn}) HeroOverlay<T>
在当前页面的 Overlay 中打开 Hero 风格弹窗。
showKeyboard() Future<void>
打开键盘
showModalSideSheet<T extends Object?>({required BuildContext context, required Widget body, bool barrierDismissible = false, Color barrierColor = const Color(0x80000000), double? width, double elevation = 8.0, Duration transitionDuration = const Duration(milliseconds: 300), String? barrierLabel = "Side Sheet", bool useRootNavigator = true, RouteSettings? routeSettings, bool ignoreAppBar = true, Color? backgroundColor}) Future<T?>
Displays a Material Side Sheet transitioned from Right side of the screen.
showPickerDialog<T>(BuildContext context, {required List<T> data, String? title, TextStyle? titleStyle, TextStyle? confirmStyle, required Widget itemBuilder(T), double itemExtent = 32}) Future<T?>
toast(String? message, {double radius = 16, EdgeInsets? padding, TextStyle textStyle = const TextStyle(color: Colors.black), VoidCallback? onDismiss, bool dismissOtherToast = true, TextAlign textAlign = TextAlign.center, Duration duration = const Duration(seconds: 3), Color backgroundColor = Colors.white, bool error = false, Alignment alignment = Alignment.center, bool showIcon = true}) → void
toString(Object object) String
通用的toString
waitFor(FutureOr<bool> fn(), {Duration delayFactor = const Duration(milliseconds: 200), int maxAttempts = 8, String message = '等待'}) Future<void>
等待某个操作符合要求

Typedefs

AnimatedScaleButton = SpringContainer
Bottom = AlignBottom
Constellation = Zodiac
ContextCallback = void Function(BuildContext context)
ContextValueChanged<T> = void Function(BuildContext context, T value)
Converter<T> = String Function(T data)
Coordinate2D = ({double latitude, double longitude})
DefaultTransformer = SyncTransformer
DeserializeCallback<T> = T Function(dynamic json)
DioError = DioException
DioError describes the exception info when a request failed.
DioErrorType = DioExceptionType
Deprecated in favor of DioExceptionType and will be removed in future major versions.
DioExceptionReadableStringBuilder = String Function(DioException e)
The readable string builder's signature of DioException.readableStringBuilder.
DioMediaType = MediaType
The type (alias) for specifying the content-type of the MultipartFile.
End = AlignEnd
FutureCallback = Future<void> Function()
FutureValueChanged<T> = Future<void> Function(T value)
HeaderForEachCallback = void Function(String name, List<String> values)
The signature that iterates header fields.
HeroOverlayFlightBuilder = Widget Function(BuildContext context, Widget child)
Hero 弹窗共享元素飞行内容的构造器。
InitCallback<T extends BLoC> = void Function(T bloc)
InterceptorErrorCallback = void Function(DioException error, ErrorInterceptorHandler handler)
The signature of Interceptor.onError.
InterceptorSendCallback = void Function(RequestOptions options, RequestInterceptorHandler handler)
The signature of Interceptor.onRequest.
InterceptorSuccessCallback = void Function(Response response, ResponseInterceptorHandler handler)
The signature of Interceptor.onResponse.
JsonDecodeCallback = FutureOr Function(String)
The callback definition for decoding a JSON string.
JsonEncodeCallback = FutureOr<String> Function(Object)
The callback definition for encoding a JSON object.
LateInitCallback<T extends BLoC> = void Function(T bloc, BuildContext context)
Left = AlignLeft
LoadingBuilder = Widget Function(BuildContext context, String loadingText)
LoadingProgress = void Function(double progress, List<int> data)
LoadMoreCallback = FutureOr Function()
Mapper = Computed
MergeListCallback<T> = List<T> Function(List<T> current, List<T> newList)
NoMoreDataCallback<T> = bool Function(List<T> newList)
OnUpdateCallback<R, T> = Future<R> Function(T arg)
OnUpdatePageCallback<R, T> = Future<R> Function(int page, T arg)
PersistSelectable = Selectable
可持久化
ProgressCallback = void Function(int count, int total)
The type of a progress listening callback when sending or receiving data.
ReactiveSwitch = NotifierSwitch
RequestEncoder = FutureOr<List<int>> Function(String request, RequestOptions options)
The type of a request encoding callback.
ResponseDecoder = FutureOr<String?> Function(List<int> responseBytes, RequestOptions options, ResponseBody responseBody)
The type of a response decoding callback.
RoundedCheckbox = CircleCheckbox
SearchKeywordCallback<T> = bool Function(T, String keyword)
SerializeCallback<T> = dynamic Function(T data)
Start = AlignStart
TextMetricsKey = (String, TextStyle, double)
Top = AlignTop
ValidateStatus = bool Function(int? status)
The type of a response status code validate callback.
ValuePredicate<T> = bool Function(T value)
VisibilityBuilder = RxVisibility
WidgetValueBuilder<T> = Widget Function(BuildContext context, T value)

Exceptions / Errors

BizError
DioException
DioException describes the exception info when a request failed.
NotNullableError<T>
A TypeError thrown by _checkNotNullable.
ValueStreamError
The error throw by ValueStream.value or ValueStream.error.