DecoratedList class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- DecoratedList
- Available extensions
Constructors
-
DecoratedList.box({Key? key, EdgeInsets? padding, String? restorationId, bool shrinkWrap = false, IndexedWidgetBuilder? itemBuilder, int? itemCount, List<
Widget> ? children, ScrollViewKeyboardDismissBehavior keyboardDismissBehavior = ScrollViewKeyboardDismissBehavior.onDrag, Axis? scrollDirection, double? width, double? height, bool addAutomaticKeepAlives = true, bool addRepaintBoundaries = true, bool addSemanticIndexes = true, double? itemExtent, ItemExtentBuilder? itemExtentBuilder, Widget? prototypeItem, ScrollController? controller, bool? expanded, BoxDecoration? decoration, ScrollPhysics? physics, Clip clipBehavior = Clip.hardEdge, bool reverse = false, @Deprecated('使用decoratedScrollableConfig代替, 已无作用') TopDividerConfig? topDivider, DecoratedScrollableConfig? decoratedScrollableConfig, EdgeInsets? margin, LoadMoreConfig? loadMoreConfig}) -
const
- DecoratedList.boxSeparated({Key? key, EdgeInsets? padding, String? restorationId, bool shrinkWrap = false, IndexedWidgetBuilder? itemBuilder, required int? itemCount, ScrollViewKeyboardDismissBehavior keyboardDismissBehavior = ScrollViewKeyboardDismissBehavior.onDrag, Axis? scrollDirection, double? width, double? height, bool addAutomaticKeepAlives = true, bool addRepaintBoundaries = true, bool addSemanticIndexes = true, ScrollController? controller, bool? expanded, BoxDecoration? decoration, required IndexedWidgetBuilder? separatorBuilder, ScrollPhysics? physics, bool reverse = false, Clip clipBehavior = Clip.hardEdge, @Deprecated('使用decoratedScrollableConfig代替, 已无作用') TopDividerConfig? topDivider, DecoratedScrollableConfig? decoratedScrollableConfig, EdgeInsets? margin, LoadMoreConfig? loadMoreConfig})
-
const
-
DecoratedList.sliver({Key? key, EdgeInsets? padding, IndexedWidgetBuilder? itemBuilder, int? itemCount, List<
Widget> ? children, IndexedWidgetBuilder? separatorBuilder, double? width, double? height, bool addAutomaticKeepAlives = true, bool addRepaintBoundaries = true, bool addSemanticIndexes = true, double? itemExtent, ItemExtentBuilder? itemExtentBuilder, Widget? prototypeItem}) -
const
Properties
- addAutomaticKeepAlives → bool
-
final
- addRepaintBoundaries → bool
-
final
- addSemanticIndexes → bool
-
final
-
children
→ List<
Widget> ? -
final
- clipBehavior → Clip
-
final
- controller → ScrollController?
-
final
- decoratedScrollableConfig → DecoratedScrollableConfig?
-
滚动decoration
final
- decoration → BoxDecoration?
-
final
- expanded → bool?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double?
-
final
- itemBuilder → IndexedWidgetBuilder?
-
final
- itemCount → int?
-
final
- itemExtent → double?
-
final
- itemExtentBuilder → ItemExtentBuilder?
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- keyboardDismissBehavior → ScrollViewKeyboardDismissBehavior
-
final
- loadMoreConfig → LoadMoreConfig?
-
box列表的加载更多配置。sliver版本不处理加载更多。
final
- margin → EdgeInsets?
-
final
- padding → EdgeInsets?
-
final
- physics → ScrollPhysics?
-
final
- prototypeItem → Widget?
-
final
- restorationId → String?
-
final
- reverse → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scrollDirection → Axis?
-
final
- separatorBuilder → IndexedWidgetBuilder?
-
final
- shrinkWrap → bool
-
final
- topDivider → TopDividerConfig?
-
滚动时是否显示顶部的分割线
final
- width → double?
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator +(
InlineSpan otherSpan) → Text -
operator ==(
Object other) → bool -
The equality operator.
inherited