LoadMoreConfig class

Constructors

LoadMoreConfig({required LoadMoreCallback onLoadMore, double loadMoreTriggerExtent = 200, bool hasMoreData = true, Widget? noMoreDataPlaceholder, bool showNoMoreDataPlaceholder = true})
const

Properties

effectiveNoMoreDataPlaceholder Widget?
no setter
hashCode int
The hash code for this object.
no setterinherited
hasMoreData bool
是否还有更多数据。
final
loadMoreTriggerExtent double
距离列表末尾小于等于此距离时触发onLoadMore,单位为逻辑像素。
final
noMoreDataPlaceholder Widget?
没有更多数据时展示的占位组件,null时使用全局默认值。
final
onLoadMore LoadMoreCallback
加载更多回调,返回false时表示没有更多数据。
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showNoMoreDataPlaceholder bool
是否展示没有更多数据的占位组件。
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

defaultNoMoreDataPlaceholder Widget?
no setter

Static Methods

setDefaultNoMoreDataPlaceholder(Widget? placeholder) → void