SliverStackParentData class
- Inheritance
-
- Mixed-in types
-
Properties
-
bottom
↔ double?
-
The distance by which the child's bottom edge is inset from the bottom of the stack.
getter/setter pair
-
crossAxisPosition
↔ double
-
getter/setter pair
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
height
↔ double?
-
The child's height.
getter/setter pair
-
isPositioned
→ bool
-
Whether this child is considered positioned.
no setter
-
left
↔ double?
-
The distance by which the child's left edge is inset from the left of the stack.
getter/setter pair
-
mainAxisPosition
↔ double
-
getter/setter pair
-
nextSibling
↔ RenderObject?
-
The next sibling in the parent's child list.
getter/setter pairinherited
-
paintOffset
↔ Offset
-
getter/setter pair
-
previousSibling
↔ RenderObject?
-
The previous sibling in the parent's child list.
getter/setter pairinherited
-
rect
↔ RelativeRect
-
Get or set the current values in terms of a RelativeRect object.
getter/setter pair
-
right
↔ double?
-
The distance by which the child's right edge is inset from the right of the stack.
getter/setter pair
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
top
↔ double?
-
The distance by which the child's top edge is inset from the top of the stack.
getter/setter pair
-
width
↔ double?
-
The child's width.
getter/setter pair
Methods
-
detach()
→ void
-
Clear the sibling pointers.
inherited
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
override