DecoratedApp<B extends RootBLoC> class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- DecoratedApp
- Available extensions
- Annotations
Constructors
-
DecoratedApp({Key? key, B? rootBLoC, GenerateAppTitle? onGenerateTitle, RouteFactory? onGenerateRoute, InitialRouteListFactory? onGenerateInitialRoutes, RouteFactory? onUnknownRoute, ThemeData? theme, ThemeData? darkTheme, ThemeData? highContrastDarkTheme, ThemeData? highContrastTheme, ThemeMode? themeMode, ScrollBehavior? scrollBehavior, Iterable<
LocalizationsDelegate> localizationsDelegates = const [], Iterable<Locale> supportedLocales = const <Locale>[Locale('en', 'US')], Locale? locale, String title = '', TransitionBuilder? builder, bool debugShowCheckedModeBanner = false, VoidCallback? onDispose, LocaleResolutionCallback? localeResolutionCallback, LocaleListResolutionCallback? localeListResolutionCallback, Map<Type, Action< ? actions, bool checkerboardOffscreenLayers = false, bool checkerboardRasterCacheImages = false, Color? color, bool debugShowMaterialGrid = false, Curve themeAnimationCurve = Curves.linear, Duration themeAnimationDuration = kThemeAnimationDuration, AnimationStyle? themeAnimationStyle, GlobalKey<Intent> >ScaffoldMessengerState> ? scaffoldMessengerKey, Map<ShortcutActivator, Intent> ? shortcuts, bool showPerformanceOverlay = false, bool showSemanticsDebugger = false, String? initialRoute, String? restorationScopeId, Widget? home, bool withCapturer = false, Map<String, WidgetBuilder> routes = const {}, CloseKeyboardConfig? autoCloseKeyboard = const CloseKeyboardConfig()}) -
const
-
DecoratedApp.router({Key? key, B? rootBLoC, GenerateAppTitle? onGenerateTitle, ThemeData? theme, ThemeData? darkTheme, ThemeData? highContrastDarkTheme, ThemeData? highContrastTheme, ThemeMode? themeMode, ScrollBehavior? scrollBehavior, Iterable<
LocalizationsDelegate> localizationsDelegates = const [], Iterable<Locale> supportedLocales = const <Locale>[Locale('en', 'US')], Locale? locale, String title = '', TransitionBuilder? builder, bool debugShowCheckedModeBanner = false, VoidCallback? onDispose, LocaleResolutionCallback? localeResolutionCallback, LocaleListResolutionCallback? localeListResolutionCallback, Map<Type, Action< ? actions, bool checkerboardOffscreenLayers = false, bool checkerboardRasterCacheImages = false, Color? color, bool debugShowMaterialGrid = false, Curve themeAnimationCurve = Curves.linear, Duration themeAnimationDuration = kThemeAnimationDuration, AnimationStyle? themeAnimationStyle, GlobalKey<Intent> >ScaffoldMessengerState> ? scaffoldMessengerKey, Map<ShortcutActivator, Intent> ? shortcuts, bool showPerformanceOverlay = false, bool showSemanticsDebugger = false, String? restorationScopeId, bool withCapturer = false, RouteInformationProvider? routeInformationProvider, RouteInformationParser<Object> ? routeInformationParser, RouterDelegate<Object> ? routerDelegate, RouterConfig<Object> ? routerConfig, BackButtonDispatcher? backButtonDispatcher, CloseKeyboardConfig? autoCloseKeyboard = const CloseKeyboardConfig()}) -
const
Properties
-
actions
→ Map<
Type, Action< ?Intent> > -
The default map of intent keys to actions for the application.
final
- autoCloseKeyboard → CloseKeyboardConfig?
-
是否自动关闭输入法
final
- backButtonDispatcher → BackButtonDispatcher?
-
A delegate that decide whether to handle the Android back button intent.
final
- builder → TransitionBuilder?
-
final
- checkerboardOffscreenLayers → bool
-
final
- checkerboardRasterCacheImages → bool
-
final
- color → Color?
-
The primary color to use for the application in the operating system
interface.
final
- darkTheme → ThemeData?
-
final
- debugShowCheckedModeBanner → bool
-
final
- debugShowMaterialGrid → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- highContrastDarkTheme → ThemeData?
-
final
- highContrastTheme → ThemeData?
-
final
- home → Widget?
-
final
- initialRoute → String?
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- locale → Locale?
-
final
- localeListResolutionCallback → LocaleListResolutionCallback?
-
This callback is responsible for choosing the app's locale
when the app is started, and when the user changes the
device's locale.
final
- localeResolutionCallback → LocaleResolutionCallback?
-
The signature of WidgetsApp.localeResolutionCallback.
final
-
localizationsDelegates
→ Iterable<
LocalizationsDelegate> -
final
-
final
-
final
- onDispose → VoidCallback?
-
final
- onGenerateInitialRoutes → InitialRouteListFactory?
-
final
- onGenerateRoute → RouteFactory?
-
final
- onGenerateTitle → GenerateAppTitle?
-
final
-
final
- onUnknownRoute → RouteFactory?
-
final
- restorationScopeId → String?
-
final
- rootBLoC → B?
-
final
-
routeInformationParser
→ RouteInformationParser<
Object> ? -
A delegate to parse the route information from the
routeInformationProvider into a generic data type to be processed by
the routerDelegate at a later stage.
final
- routeInformationProvider → RouteInformationProvider?
-
final
-
routerConfig
→ RouterConfig<
Object> ? -
An object to configure the underlying Router.
final
-
routerDelegate
→ RouterDelegate<
Object> ? -
A delegate that configures a widget, typically a Navigator, with
parsed result from the routeInformationParser.
final
-
routes
→ Map<
String, WidgetBuilder> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
scaffoldMessengerKey
→ GlobalKey<
ScaffoldMessengerState> ? -
final
- scrollBehavior → ScrollBehavior?
-
final
-
shortcuts
→ Map<
ShortcutActivator, Intent> ? -
final
- showPerformanceOverlay → bool
-
final
- showSemanticsDebugger → bool
-
final
-
supportedLocales
→ Iterable<
Locale> -
final
- theme → ThemeData?
-
final
- themeAnimationCurve → Curve
-
final
- themeAnimationDuration → Duration
-
final
- themeAnimationStyle → AnimationStyle?
-
final
- themeMode → ThemeMode?
-
final
- title → String
-
final
- withCapturer → bool
-
是否内建截图组件Capturer
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator +(
InlineSpan otherSpan) → Text -
operator ==(
Object other) → bool -
The equality operator.
inherited